summaryrefslogtreecommitdiffstats
path: root/core/src/renderer.rs
diff options
context:
space:
mode:
authorLibravatar Héctor Ramón Jiménez <hector@hecrj.dev>2023-10-24 05:34:03 +0200
committerLibravatar Héctor Ramón Jiménez <hector@hecrj.dev>2024-02-02 02:24:45 +0100
commitf4d66486016076bb339a338bc589645119962d1e (patch)
treebbb9c4d996216893296cf4323857323542d6e757 /core/src/renderer.rs
parenta6e91d13d5d43796d0e6bb570fb4f010cf27921a (diff)
downloadiced-f4d66486016076bb339a338bc589645119962d1e.tar.gz
iced-f4d66486016076bb339a338bc589645119962d1e.tar.bz2
iced-f4d66486016076bb339a338bc589645119962d1e.zip
Introduce `with_transformation` to `Renderer` trait
Diffstat (limited to 'core/src/renderer.rs')
-rw-r--r--core/src/renderer.rs20
1 files changed, 17 insertions, 3 deletions
diff --git a/core/src/renderer.rs b/core/src/renderer.rs
index 0af74bb3..1139b41c 100644
--- a/core/src/renderer.rs
+++ b/core/src/renderer.rs
@@ -5,7 +5,9 @@ mod null;
#[cfg(debug_assertions)]
pub use null::Null;
-use crate::{Background, Border, Color, Rectangle, Shadow, Size, Vector};
+use crate::{
+ Background, Border, Color, Rectangle, Shadow, Size, Transformation, Vector,
+};
/// A component that can be used by widgets to draw themselves on a screen.
pub trait Renderer: Sized {
@@ -14,12 +16,24 @@ pub trait Renderer: Sized {
/// The layer will clip its contents to the provided `bounds`.
fn with_layer(&mut self, bounds: Rectangle, f: impl FnOnce(&mut Self));
- /// Applies a `translation` to the primitives recorded in the given closure.
+ /// Applies a [`Transformation`] to the primitives recorded in the given closure.
+ fn with_transformation(
+ &mut self,
+ transformation: Transformation,
+ f: impl FnOnce(&mut Self),
+ );
+
+ /// Applies a translation to the primitives recorded in the given closure.
fn with_translation(
&mut self,
translation: Vector,
f: impl FnOnce(&mut Self),
- );
+ ) {
+ self.with_transformation(
+ Transformation::translate(translation.x, translation.y),
+ f,
+ );
+ }
/// Fills a [`Quad`] with the provided [`Background`].
fn fill_quad(&mut self, quad: Quad, background: impl Into<Background>);